Install DIRESA — DIRESA documentation

# Install DIRESA

Overview

DIRESA is a Python package for dimension reduction based on TensorFlow. The distance-regularized Siamese twin autoencoder architecture is designed to preserve distance (ordering) in latent space while capturing the non-linearities in the datasets.

Prerequisites

The DIRESA package depends on the tensorflow and tensorflow_probability packages. These can be installed with the following commands:

    pip install tensorflow
    pip install tensorflow_probability

Install DIRESA

Install DIRESA with the following command:

    pip install diresa